#
# spec file for package libdrm
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libdrm
Version:        2.4.100
Release:        lp152.1.1
Summary:        Userspace Interface for Kernel DRM Services
License:        MIT
Group:          Development/Libraries/X11
Url:            http://dri.freedesktop.org/
# Git-Clone:    https://gitlab.freedesktop.org/mesa/drm.git
# Git-Web:      https://gitlab.freedesktop.org/mesa/drm
# Source URL:   https://dri.freedesktop.org/libdrm/
Source:         https://dri.freedesktop.org/libdrm/%{name}-%{version}.tar.bz2
Source2:        baselibs.conf

# Required for building manpages
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  meson >= 0.43
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(pciaccess) >= 0.10
%if 0%{?with_valgrind_support:1}
%ifarch %{ix86} x86_64 ppc ppc64 ppc64le s390x %{arm}
BuildRequires:  pkgconfig(valgrind)
%endif
%endif

Provides:       libdrm23 = %{version}
Obsoletes:      libdrm23 < %{version}
# bug437293
%ifarch ppc64
Obsoletes:      libdrm-64bit < %{version}
Provides:       libdrm-64bit = %{version}
%endif

%description
The package contains the userspace interface to the kernel DRM
services.

%package tools
Summary:        Diagnostic utilities for DRI and DRM
Group:          System/Base
Obsoletes:      libdrm < %{version}-%{release}
Provides:       libdrm = %{version}-%{release}

%description tools
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems that support the ioctl
interface, and for chipsets with DRM memory manager, support for
tracking relocations and buffers. libdrm is a low-level library,
typically used by graphics drivers such as the Mesa DRI and X
drivers.

This package contains diagnostic utilities for DRI and DRM.

%package devel
Summary:        Libraries, includes and more to develop libdrm applications
Group:          Development/Libraries/X11
Requires:       libdrm2 = %{version}
Requires:       libdrm_amdgpu1 = %{version}
Requires:       libdrm_nouveau2 = %{version}
Requires:       libdrm_radeon1 = %{version}
%ifarch %{arm} aarch64
Requires:       libdrm_etnaviv1 = %{version}
Requires:       libdrm_exynos1 = %{version}
Requires:       libdrm_freedreno1 = %{version}
Requires:       libdrm_tegra0 = %{version}
%endif
%ifarch %{arm}
Requires:       libdrm_omap1 = %{version}
%endif
%ifarch %{ix86} x86_64
Requires:       libdrm_intel1 = %{version}
%endif
# bug437293
%ifarch ppc64
Obsoletes:      libdrm-devel-64bit < %{version}
Provides:       libdrm-devel-64bit = %{version}
%endif

%description devel
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems that support the ioctl
interface, and for chipsets with DRM memory manager, support for
tracking relocations and buffers. libdrm is a low-level library,
typically used by graphics drivers such as the Mesa DRI and X
drivers.

This package contains the development headers for the library found
in libdrm2.

%package -n libdrm2
Summary:        Userspace Interface for Kernel DRM Services
Group:          System/Libraries

%description -n libdrm2
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems that support the ioctl
interface, and for chipsets with DRM memory manager, support for
tracking relocations and buffers. libdrm is a low-level library,
typically used by graphics drivers such as the Mesa DRI and X
drivers.

%package -n libdrm_intel1
Summary:        Userspace interface for Kernel DRM services for Intel chips
Group:          System/Libraries

%description -n libdrm_intel1
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems.

This package provides userspace interface for Kernel DRM services
for Intel chips.

%package -n libdrm_nouveau2
Summary:        Userspace interface for Kernel DRM services for NVIDIA chips
Group:          System/Libraries

%description -n libdrm_nouveau2
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems.

This package provides userspace interface for Kernel DRM services
for NVIDIA chips.

%package -n libdrm_radeon1
Summary:        Userspace interface for Kernel DRM services for AMD Radeon chips
Group:          System/Libraries

%description -n libdrm_radeon1
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems.

This package provides userspace interface for Kernel DRM services
for AMD Radeon chips.

%package -n libdrm_amdgpu1
Summary:        Userspace interface for Kernel DRM services for AMD Radeon chips
Group:          System/Libraries

%description -n libdrm_amdgpu1
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems.

This package provides userspace interface for Kernel DRM services
for AMD Radeon chips.

%package -n libkms-devel
Summary:        Development files for the KMS MM abstraction library
Group:          Development/Libraries/C and C++
Requires:       libkms1 = %{version}

%description -n libkms-devel
This package contains the development headers for the library found
in libkms1.

%package -n libkms1
Summary:        Userspace interface to kernel DRM buffer management
Group:          System/Libraries

%description -n libkms1
The KMS Memory Management abstraction library.
This package provides the userspace interface to kernel DRM buffer management

%package -n libdrm_omap1
Summary:        Userspace interface to kernel DRM services for omap chips
Group:          System/Libraries

%description -n libdrm_omap1
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems.

This package provides userspace interface to kernel DRM services
for omap chips.

%package -n libdrm_etnaviv1
Summary:        Userspace interface to kernel DRM services for Vivante chips
Group:          System/Libraries

%description -n libdrm_etnaviv1
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems.

This package provides userspace interface to kernel DRM services
for Vivante chips.

%package -n libdrm_exynos1
Summary:        Userspace interface to kernel DRM services for Samsung Exynos chips
Group:          System/Libraries

%description -n libdrm_exynos1
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems.

This package provides userspace interface to kernel DRM services
for Samsung Exynos chips.

%package -n libdrm_freedreno1
Summary:        Userspace interface to kernel DRM services for Qualcomm Adreno chips
Group:          System/Libraries

%description -n libdrm_freedreno1
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems.

This package provides userspace interface to kernel DRM services
for Qualcomm Adreno chips.

%package -n libdrm_tegra0
Summary:        Userspace interface to kernel DRM services for Nvidia Tegra chips
Group:          System/Libraries

%description -n libdrm_tegra0
libdrm is a library for accessing the Direct Rendering Manager on
Linux, BSD and other operating systems.

This package provides userspace interface to kernel DRM services
for Nvidia Tegra chips.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%meson \
	--default-library=shared \
	-Dinstall-test-programs=true \
	-Dudev=true \
%ifarch %{arm}
	-Domap=true \
%endif
%ifarch %{arm} aarch64
	-Detnaviv=true \
	-Dexynos=true \
	-Dfreedreno=true \
	-Dtegra=true \
%endif
%ifnarch %{ix86} x86_64 ppc ppc64 ppc64le s390x %{arm}
	-Dvalgrind=false \
%else
%if 0%{!?with_valgrind_support:1}
	-Dvalgrind=false \
%endif
%endif
	%{nil}
%meson_build

%check
### FIXME ### Tests fail on arm, so lets not run them there for now.
%ifnarch %{arm}
%meson_test
%endif

%install
%meson_install
%fdupes %{buildroot}/%{_prefix}

%post   -n libdrm2 -p /sbin/ldconfig
%postun -n libdrm2 -p /sbin/ldconfig
%post   -n libdrm_intel1 -p /sbin/ldconfig
%postun -n libdrm_intel1 -p /sbin/ldconfig
%post   -n libdrm_nouveau2 -p /sbin/ldconfig
%postun -n libdrm_nouveau2 -p /sbin/ldconfig
%post   -n libdrm_radeon1 -p /sbin/ldconfig
%postun -n libdrm_radeon1 -p /sbin/ldconfig
%post   -n libdrm_amdgpu1 -p /sbin/ldconfig
%postun -n libdrm_amdgpu1 -p /sbin/ldconfig
%post   -n libkms1 -p /sbin/ldconfig
%postun -n libkms1 -p /sbin/ldconfig

%ifarch %{arm}
%post   -n libdrm_omap1 -p /sbin/ldconfig
%postun -n libdrm_omap1 -p /sbin/ldconfig
%endif

%ifarch %{arm} aarch64
%post   -n libdrm_etnaviv1 -p /sbin/ldconfig
%postun -n libdrm_etnaviv1 -p /sbin/ldconfig
%post   -n libdrm_exynos1 -p /sbin/ldconfig
%postun -n libdrm_exynos1 -p /sbin/ldconfig
%post   -n libdrm_freedreno1 -p /sbin/ldconfig
%postun -n libdrm_freedreno1 -p /sbin/ldconfig
%post   -n libdrm_tegra0 -p /sbin/ldconfig
%postun -n libdrm_tegra0 -p /sbin/ldconfig
%endif

%files tools
%ifarch %arm aarch64
%{_bindir}/etnaviv_2d_test
%{_bindir}/etnaviv_bo_cache_test
%{_bindir}/etnaviv_cmd_stream_test
%{_bindir}/exynos_fimg2d_test
%{_bindir}/exynos_fimg2d_event
%{_bindir}/exynos_fimg2d_perf
%endif
%{_bindir}/kms-steal-crtc
%{_bindir}/kms-universal-planes
%{_bindir}/kmstest
%{_bindir}/modeprint
%{_bindir}/modetest
%{_bindir}/proptest
%{_bindir}/vbltest

%files devel
%{_mandir}/man?/drm*?%{ext_man}
%{_includedir}/libdrm
%ifarch %{arm}
%{_includedir}/omap
%endif
%ifarch %{arm} aarch64
%{_includedir}/exynos
%{_includedir}/freedreno
%endif
%{_includedir}/xf86drm.h
%{_includedir}/xf86drmMode.h
%{_includedir}/libsync.h
%{_libdir}/libdrm*.so
%{_libdir}/pkgconfig/libdrm*.pc

%files -n libdrm2
%{_libdir}/libdrm.so.2*
%dir %{_datarootdir}/libdrm

%ifarch %{ix86} x86_64
%files -n libdrm_intel1
%{_libdir}/libdrm_intel.so.1*
%endif

%files -n libdrm_nouveau2
%{_libdir}/libdrm_nouveau.so.2*

%files -n libdrm_radeon1
%{_libdir}/libdrm_radeon.so.1*

%files -n libdrm_amdgpu1
%{_libdir}/libdrm_amdgpu.so.1*
%{_datarootdir}/libdrm/amdgpu.ids

%files -n libkms1
%{_libdir}/libkms.so.1*

%files -n libkms-devel
%{_includedir}/libkms
%{_libdir}/libkms.so
%{_libdir}/pkgconfig/libkms.pc

%ifarch %{arm}
%files -n libdrm_omap1
%{_libdir}/libdrm_omap.so.1*
%endif

%ifarch %{arm} aarch64
%files -n libdrm_etnaviv1
%_libdir/libdrm_etnaviv.so.1*

%files -n libdrm_exynos1
%_libdir/libdrm_exynos.so.1*

%files -n libdrm_freedreno1
%{_libdir}/libdrm_freedreno.so.1*

%files -n libdrm_tegra0
%{_libdir}/libdrm_tegra.so.0*
%endif

%changelog
* Thu Nov  7 2019 Stefan Dirsch <sndirsch@suse.com>
- This release includes support for latest Intel GPUs
  (jsc#SLE-7962, jsc#SLE-8024, jsc#SLE-8022, jsc#SLE-10182,
  jsc#SLE-4989, jsc#SLE-4983, bsc#1137515)
* Wed Oct 30 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.4.100
  * bugfixes (boo#1155382)
* Wed Jul  3 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.4.99
  * bug fixes
* Tue Apr 23 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.4.98
  * This release adds marketing names for AMDGPU devices, a
    fallback path in drmDevice for devices lacking OF data
    and drmIsMaster API, amongst other changes.
* Mon Feb 11 2019 sndirsch@suse.com
- back to subpackage name libdrm-tools as requested by
  jengelh@inai.de
* Thu Jan 24 2019 bjorn.lie@gmail.com
- Switch to meson buildsystem:
  * Update Git-clone/web to new gitlab home.
  * Add meson BuildRequires and macros.
  * Add fdupes BuildRequires and macros, remove duplicate files.
  * Rename libdrm-tools to drm-tools, follow openSUSE packaging
    guidelines and silence a rpmlint warning. Add Obsoletes and
    Provides to ensure smooth upgrades.
  * Tweak descriptions for several sub-packages.
  * Drop custom test install and run, run plain meson_test provided
    by upstream.
* Tue Jan 22 2019 sndirsch@suse.com
- Update to version 2.4.97
  * amdgpu: update to latest marketing names from 18.50
  * amdgpu/test: Add illegal register and memory access test v2
  * amdgpu/test: Disable deadlock tests for all non gfx8/9 ASICs.
  * amdgpu/test: Enable deadlock test for CI family (gfx7)
  * amdgpu: add VM test to exercise max/min address space
  * doc: Rename README&CONTRIBUTING to .rst
  * Avoid hardcoded strlens in drmParseSubsystemType().
  * drm: Attempt to parse SPI devices as platform bus devices.
  * xf86drmHash: remove unused loop variable
  * meson: fix typo in compiler flag
  * tests: skip drmdevice test if the machine doesn't have any drm device
  * freedreno: remove always-defined #ifdef
  * xf86atomic: #undef internal define
  * README: reflow the project description to improve readability
  * xf86drm: implement drmParseSubsystemType for DragonFly
  * libdrm: Use DRM_IOCTL_GET_PCIINFO on DragonFly
  * tests/amdgpu/vcn: fix the nop command in IBs
  * gitignore: sort file
  * gitignore: add _build
  * amdgpu: update amdgpu_drm.h
  * amdgpu: add a faster BO list API
  * android: Fix 32-bit app crashing in 64-bit Android
* Wed Dec 19 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable aarch64 build for: etnaviv, exynos and tegra
* Wed Dec 19 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix --enable-freedreno option as it is not experimental anymore
- Add etnaviv support
- Add exynos support (used by Arndale board and Samsung Chromebook)
* Wed Oct 17 2018 sndirsch@suse.com
- Update to version 2.4.96
  * libdrm: Allow dynamic drm majors on linux
  * amdgpu/test: Allow BO mapping flags to be passed in tests
  * amdgpu/test: Fix deadlock tests for AI and RV v2
  * xf86drmHash: remove redundant zero init
  * freedreno/msm: get rid of ring_bo unref hack
  * freedreno: expose refcnt'ing on ringbuffers
  * freedreno: add flags param for rb creation
  * freedreno/msm: support suballocation for stateobj rb's
  * freedreno: remove deprecated ringmarker API
  * freedreno/msm: remove reset of linked rings
  * freedreno/msm: simplify emit_reloc_ring() vfunc
  * freedreno/msm: use hashtable to track submit.cmds table
  * freedreno/msm: simplify msm_ringbuffer_flush()
  * freedreno/msm: handle ring-reloc to other stateobjs
  * freedreno/kgsl: fix build
  * freedreno/msm: fix c90 warning
* Sun Oct  7 2018 sndirsch@suse.com
- Update to version 2.4.95
  * This release adds a fallback for realpath() which was blocked by the
    web-browser sand-boxing. While the browsers are fixed-up they seem to have
    little incentive to roll bugfix releases :-\
* Sat Aug  4 2018 tobias.johannes.klausmann@mni.thm.de
- Upate to version 2.4.93:
  + amdgpu: make sure to set CLOEXEC on duplicated FDs
  + xf86drm: drmGetDevice2: error out if the fd has unknown subsys
  + xf86drm: introduce drm_device_has_rdev() helper
  + xf86drm: Fold drmDevice processing into process_device() helper
  + xf86drm: Allocate drmDevicePtr's on stack
  + xf86drm: introduce a get_real_pci_path() helper
  + xf86drm: Add drmDevice support for virtio_gpu
  + tests/drmdevices: install alongside other utilities
  + tests/drmdevice: add a couple of printf headers
  + drmdevice: convert the tabbed output into a tree
  + drmdevice: print the correct host1x information
  + amdgpu: Take a lock before removing devices from fd_tab hash table.
  + amdgpu/util_hash_table: Add helper function to count the number of entries in hash table
  + amdgpu: Destroy fd_hash table when the last device is removed.
  + intel: Introducing Whiskey Lake platform
  + intel: Introducing Amber Lake platform
  + xf86drm: Be sure to closedir before return
  + amdgpu: don't call add_handle_to_table for KMS BO exports
  + amdgpu: add amdgpu_bo_handle_type_kms_noimport
  + xf86drm: Fix error path in drmGetDevice2
  + Always pass O_CLOEXEC when opening DRM file descriptors
  + Revert "amdgpu: don't call add_handle_to_table for KMS BO exports"
  + freedreno: add user ptr to fd_ringbuffer
  + freedreno: add fd_ringbuffer_new_object()
  + freedreno: small cleanup
  + freedreno: slight reordering
  + freedreno/msm: "stateobj" support
* Thu May 10 2018 mimi.vx@gmail.com
- update to 2.4.92
  + drm/atomic: Refuse to add invalid objects to requests
  + freedreno: add missing symbols to symbol-check
  + libdrm: Use readdir instead of readdir_r to avoid build warnings
  + Intel: Add a Kaby Lake PCI ID
  + amdgpu: Deinitialize vamgr_high{,_32}
  + intel: add support for ICL 11
  + amdgpu:support 16 ibs per submit for PAL/SRIOV
  + freedreno: add fd_pipe refcounting
  + drm/amdgpu: Remove IB count checking
  + intel/intel_chipset.h: Sync Cannonlake IDs.
  + libdrm: amdgpu: Adding DRM_RDWR flag in amdgpu_bo_export
  + amdgpu: enlarge the maximum number of cards supported
* Tue Mar  6 2018 mimi.vx@gmail.com
- update to 2.4.91
  + amdgpu: Fix mistake in initial hole size calculation.
  + amdgpu: mostly revert "use the high VA range if possible v2"
  + amdgpu: add AMDGPU_VA_RANGE_HIGH
  + amdgpu: fix "add AMDGPU_VA_RANGE_HIGH"
  + freedreno: add interface to get buffer address
  + drm/fourcc: Fix fourcc_mod_code() definition
  + drm/tegra: Sanitize format modifiers
* Wed Feb 21 2018 emil.l.velikov@gmail.com
- Remove unneeded defattr stanza
* Wed Feb 21 2018 emil.l.velikov@gmail.com
- Remove pthread-stubs dependency
* Wed Feb 21 2018 emil.l.velikov@gmail.com
- Remove unneeded autotool dependencies
* Sat Feb 17 2018 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.90:
  + Add meson build system
  + always define HAVE_FREEDRENO_KGSL
  + always define HAVE_CAIRO
  + always define HAVE_VALGRIND
  + amdgpu: Update deadlock test to not assert on ECANCELED
  + amdgpu: Fix segfault in deadlock test.
  + amdgpu: fix 32bit VA manager max address
  + amdgpu: use the high VA range if possible v2
  + amdgpu: fix high VA mask
  + amdgpu: fix inefficient vamgr algorithm
  + amdgpu: clean up non list code path for vamgr v2
  + amdgpu: add amdgpu_query_sw_info for querying high bits of 32-bit address space
  + amdgpu: Don't print error message if parse_one_line returned -EAGAIN
  + amdgpu: Don't dereference device_handle after amdgpu_device_deinitialize
  + amdgpu: Symlink .editorconfig to tests/amdgpu
  + amdgpu: Disable deadlock test suite by default for SI ASICs
  + amdgpu: Disable VM test suite by default for SI ASICs
  + amdgpu: Add amdgpu_query_sw_info to amdgpu-symbol-check
  + amdgpu: fix not to add amdgpu.ids when building without amdgpu
  + android: Move gralloc handle struct to libdrm
  + android: Add version variable to gralloc_handle_t
  + android: Mark gralloc_handle_t magic variable as const
  + android: Remove member name from gralloc_handle_t
  + android: Change gralloc_handle_t members to be fixed width
  + autotools: Include meson.build files in tarball
  + configure: remove unused HAVE_CUNIT define
  + configure: remove unused HAVE_INSTALL_TESTS define
  + configure: always define HAVE_LIBDRM_ATOMIC_PRIMITIVES and HAVE_LIB_ATOMIC_OPS
  + drm: Fix 32-bit drmSyncobjWait.
  + exynos/tests: use #ifdef for never-defined token
  + fix return value for syncobj wait
  + freedreno: clamp priority based on # of rings
  + headers: sync up amdgpu_drm.h with drm-next
  + intel: Add more Coffeelake PCI IDs
  + meson: fix the install path of amdgpu.ids
  + meson: set proper pkg-config version for libdrm_freedreno
  + meson: set the minimum version correctly
  + meson: fix libdrm_nouveau pkgconfig include directories
  + meson: include headers in root directory in ext_libdrm
  + meson: cleanup whitespace
  + meson: add missing HAVE_RADEON
  + meson: sort HAVE_* defines
  + meson,configure: remove unused HAVE_OMAP define
  + meson,configure: remove unused HAVE_TEGRA define
  + meson,configure: remove unused HAVE_FREEDRENO define
  + meson,configure: remove unused HAVE_ETNAVIV define
  + meson,configure: always define HAVE_{INTEL,VMWGFX,NOUVEAU,EXYNOS,VC4,RADEON}
  + meson,configure: turn undefined preprocessor tokens warnings into errors
  + meson,configure: add warning when using undefined preprocessor tokens
  + modetest: Fix to check return value of asprintf()
  + remove unnecessary double-semicolon
  + README: Add note about meson
  + test/amdgpu: fix compiler warnings
  + tests/amdgpu: add bo eviction test
  + tests/amdgpu: add missing config.h include
  + tests/amdgpu: add parentheses to make operation priority explicit
  + tests/amdgpu: drop unused variables
  + tests/amdgpu: execute write linear on all the available rings
  + tests/amdgpu: execute const fill on all the available rings
  + tests/amdgpu: execute copy linear on all the available rings
  + tests/etnaviv: drop unused `return 0`
  + tests/util: fix signed/unsigned comparisons
  + tests/util: drop unused parameters
  + xf86drmHash: remove always-false #if guards
  + xf86atomic: fix -Wundef warning
- Remove upstreamed patch U_intel-Add-more-Coffeelake-PCI-IDs.patch
* Mon Jan 15 2018 sndirsch@suse.com
- U_intel-Add-more-Coffeelake-PCI-IDs.patch
  * Add more Coffeelake PCI IDs (request by Intel)
* Mon Dec 18 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.89:
  libdrm release with leasing and syncobj api updates, updated amdgpu marketing
  ids, amdgpu tests, updated uapi headers & etnaviv updates.
* Sun Nov  5 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.88:
  + amdgpu: Fix wrappers for AMDGPU_VM IOCTL.
* Wed Nov  1 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.87:
  + amdgpu: fix 32-bit build
- This release includes the changes introduced with 2.4.86:
  + amdgpu: Add wrappers for AMDGPU_VM IOCTL.
  + amdgpu: Add VMID reservation per GPU context test.
  + drm: sync drm headers from drm-next.
  + drm/syncobj: fix some whitespace issues
* Mon Oct 23 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.85:
  + Add const qualifier to arguments of drmModeAddFB2()
  + amdgpu: implement context priority for amdgpu_cs_ctx_create2 v3
  + amdgpu: add padding to the fence to handle ioctl
  + headers: Sync amdgpu_drm.h with drm-next
  + modetest: Decode IN_FORMATS plane blob property
  + modetest: Allow full testing of primary planes
- Fix changelog entry for version 2.4.84
* Thu Oct 12 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.84:
  + amdgpu: Add deadlock detection test suit.
  + amdgpu: make userptr unit test more interesting
  + amdgpu: Do not write beyond allocated memory when parsing ids
  + amdgpu: print error messages when amdgpu_device_initialize is failing
  + amdgpu: add sync_file import and export functions
  + amdgpu: add amdgpu_cs_syncobj_wait
  + amdgpu: add amdgpu_cs_fence_to_handle
  + Android: move libraries to /vendor
  + drm: add drmSyncobjWait wrapper
  + etnaviv: prevent deadlock in error path
  + freedreno/kgsl: fix pointer-to-int cast
  + headers: sync syncobj ioctl defines.
  + headers: sync DRM_MODE_ROTATE/REFLECT defines from kernel v4.14-rc1
  + intel: Change a KBL pci id to GT2 from GT1.5
  + include: sync drm.h and amdgpu_drm.h with airlied/drm-next
  + tests/amdgpu: add missing header to SOURCES
  + tests/amdgpu: add new uvd enc support check
  + tests/amdgpu: fix uvd enc data corruption issue
* Sat Sep 30 2017 jengelh@inai.de
- Remove --with-pic which has no effect on shared-only builds.
  Rectify SRPM group.
* Fri Aug 25 2017 sndirsch@suse.com
- Update to version 2.4.83
  + amdgpu: Add FX-9800P Bristol Ridge iGPU id
  + amdgpu: fix missing mutex unlock before return
  + amdgpu: fix race issue between two bo functions(v2)
  + amdgpu: merge and cleanup amdgpu_bo_free
  + android: add rules to build amdgpu.ids
  + android: amdgpu: fix build break
  + drm: Pull new modifier uapi into drm_fourcc and drm_mode
  + drmsltest: Check expected neighbours
  + etnaviv: fix etna_bo_from_name
  + freedreno: remove dead error path
  + freedreno: prevent deadlock in error path
  + freedreno/msm: remove dead error path
  + radeon: add fallthrough annotation
  + test/amdgpu: fix test failure for SI
  + tests/amdgpu: bypass UVD CS tests on raven
  + tests/amdgpu: bypass VCE tests on raven
  + tests/amdgpu: add uvd encode unit tests
  + xf86drm: continue with next device if drmProcessUsbDevice fails
  + xf86drm: continue after drmProcessPlatformDevice failure
* Wed Aug  2 2017 ro@suse.de
- build-require util-macros-devel for suse_version > 1320
* Thu Jul 20 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.82:
  + intel: PCI Ids for S SKU in CFL
  + intel: PCI Ids for H SKU in CFL
  + intel: PCI Ids for U SKU in CFL
  + intel/gen10: Add missed gen10 stuff
  + etnaviv: submit full struct drm_etnaviv_gem_submit
  + amdgpu: sync amdgpu_drm with kernel.
  + drm: update drm.h to latest in drm-next.
  + libdrm: add drm syncobj create/destroy/import/export
  + drm/amdgpu: add syncobj create/destroy/import/export apis
  + drm/amdgpu: add new low overhead command submission API. (v2)
  + amdgpu: add new symbols to tests.
  + Android's major/minor/makedev live in <sys/sysmacros.h>
  + headers: Update drm_fourcc and vc4_drm.h with new VC4 tiling UAPI.
  + headers: sync drm_fourcc.h with airlied/drm-next
  + headers: sync drm_sarea.h with airlied/drm-next
  + tests/amdgpu: rename uvd messages to decode messages
  + tests/amdgpu: separate decode messages
  + tests/amdgpu: move decode sum to common
  + tests/amdgpu: add vcn tests support and sets
  + tests/amdgpu: implement vcn dec unit tests
  + tests/amdgpu: s/uvd_messages.h/decode_messages.h/ in Makefile.am
  + tests/amdgpu: Fix device_id option
  + amdgpu: Add .editorconfig file for amdgpu coding style
  + intel: add GEN10 to IS_9XX.
  + Android: fix missing trailing \
  + intel: Add Cannonlake PCI IDs for U-skus.
  + intel: Add Cannonlake PCI IDs for Y-skus.
  + intel/intel_chipset: Move IS_9XX below IS_GEN10.
  + amdgpu: move asic id table to a separate file
  + Remove redundant memclear
* Fri May 26 2017 sndirsch@suse.com
- Update to version 2.4.81
  * Export drmDevicesEqual
  * configure: Fix the <sys/sysmacros.h> check
  * Fix stray caller of drmCompareDevices
  * amdgpu/: concisely && consistently check null ptrs in canonical form
  * amdgpu: Use the canonical form in branch predicate
  * Add pl111 as a KMS driver for utils.
  * Add the DPI encoder/connector types to KMS utils.
  * amdgpu: add raven family id
  * modetest: fix printing of fourcc on BE machines
  * amdgpu/drm: add AMDGPU_HW_IP_VCN_DEC
  * amdgpu/drm: add AMDGPU_HW_IP_VCN_ENC
  * amdgpu: add the interface of waiting multiple fences
  * amdgpu: add a test for amdgpu_cs_wait_fences
  * amdgpu: add missing extern "C" headers
  * freedreno: fix double-free on exit
* Mon Apr 17 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.80:
  + intel: remove dead code
  + etnaviv: sync uapi header
  + etnaviv: add fence fd support
  + exynos: add C++ support to exynos_drmif header
* Wed Apr 12 2017 sndirsch@suse.com
- SLE merge
  * Mesa 17.0.3 build on aarch64 needs libdrm_freedreno >= 2.4.74
    (fate#321223)
  * latest libdrm version for sle12 (fate #315643-315645, 319159-319161, 319618)
* Mon Apr 10 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.79:
  + amdgpu: allow to query GPU sensor related information
- Update to version 2.4.78:
  This fixes a build issue for GNU/kFreeBSD, and adds a new
  page_flip_handler2 event handler, which when run on a suitably
  capable kernel, can provide the CRTC ID to userspace for atomic
  completion events.
* Sat Apr  8 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.77:
  + tests/etnaviv: link against libdrm
  + etnaviv: remove struct etna_specs
  + amdgpu: add amdgpu_bo_va_op_raw to the symbol check
  + configure.ac: bring back pthread-stubs check
  + tegra: update symbol-check
  + amdgpu: add REPLACE and CLEAR checking for VA op (v2)
  + amdgpu: add amdgpu_bo_va_op_raw
  + headers: sync amdgpu_drm.h from airlied/drm-next
  + headers: the uint*_t vs. __u* discrepancy in amdgpu_drm is fixed
  + Android: fix building of modetest and proptest
  + Android: disable pointer-arith and enum-conversion
  + exynos: fix type-punned pointer build warning
  + exynos/fimg2d: remove unused-function build warning
  + tests/exynos: remove unused-function build warning
  + tests/exynos: fix invalid code of error path in g2d test
  + xf86drm: remove memory leaks in drmGetBusid/drmGetReservedContextList
* Tue Apr  4 2017 sndirsch@suse.com
- do not buildrequire util-macros-devel on sle13
* Thu Mar 30 2017 sndirsch@suse.com
- update to 2.4.76
  * This release is required for upcoming Radeon Vega GPUs.
* Sat Jan 28 2017 mimi.vx@gmail.com
- update to 2.4.75
  * amdgpu: Provide more specific error message if non-privileged user runs amdgpu_test
  * amdgpu: verify the tested device
  * amdgpu: A new option to choose which device to run most tests
  * amdgpu: A new option to run tests on render node
  * Import uapi/i915_drm.h from v4.10-rc5-950-g152d5750dda9
  * intel: Allow the client to control implicit synchronisation
  * intel: Support passing of explicit fencing from execbuf
  * intel: Clear execobject flags before preserving object in reuse cache
  * intel: Export a function to re-enable implicit synchronisation
  * intel: update global_name before HASH_ADD
  * xf86drm: use maj/min in drmParsePciDeviceInfo()
  * xf86drm: add plumbing to not retrieve PCI device revision
  * xf86drm: parse the separate sysfs files for vendor... info
  * xf86drm: introduce drmGetDevice[s]2
  * tests/drmdevice: use drmGetDevice[s]2
  * tests: remove useless legacy tests
  * kms: remove commented out libudev code
  * configure: remove libudev checks
  * tests: automake: reorder makefile contents
  * autogen.sh: set format.subjectPrefix and sendemail.to if needed
  * android: remove LOCAL_MODULE_TAGS := optional tag
  * android: introduce Android.common.mk to reduce boilerplate
  * android: add HAVE_VISIBILITY to Android.common.mk
  * android: add note about command line defines and config.h
  * android: silence ~550 warnings
  * tests/nouveau: automake: fold C and CPP flags
  * xf86drm: fix sign-compare warning
  * xf86drm: implement drmGetMinorNameForFD for non-sysfs
  * xf86drm: implement drmParseSubsystemType for OpenBSD
  * xf86drm: implement drmParsePciDeviceInfo for OpenBSD
  * xf86drm: implement drmParsePciBusInfo for OpenBSD
  * xf86drm: implement an OpenBSD specific drmGetDevice2
  * xf86drm: adjust device node path for minor base
  * xf86drm: add a non-sysfs version of drmGetDeviceNameFromFd2
  * xf86drm: don't fatal on per device error in drmGetDevice[s]2
  * tests/util: Add support for meson module
  * libkms/exynos: fix memory leak in error path
  * xf86drm: fix null termination of string buffer
  * xf86drm: Fix indentation
  * xf86drmMode.h: Use consistent padding
  * xf86drmMode.h: Add DisplayPort MST and DPI encoders/connectors
  * xf86drm: Fix type-punned pointer build warning
  * xf86drm: Factor out drmDeviceAlloc()
  * xf86drm: Add USB support
  * xf86drm: Add platform and host1x bus support
  * tests/drmdevice: Add USB, platform and host1x support
  * xf86drm: Reuse sysfs_uevent_get()
  * tests: Use -pthread in CFLAGS instead of -lpthread
  * modetest: Allow the user to specify the plane ID
* Wed Jan 25 2017 sndirsch@suse.com
- enabled build of manual pages (bnc#1021810)
* Sat Dec 31 2016 chris@computersalat.de
- update to 2.4.74
  * vc4: Add new GETPARAMs that have been merged to drm-next
  * freedreno: 64bit support
  * etnaviv: add etna_pipe_wait_ns(..)
  * etnaviv: change get_abs_timeout(..) to use ns
  * libdrm: random typo fixes
  * tests: kms: fix shadowed declaration warning
  * xf86drm: introduce drmGetDeviceNameFromFd2
  * automake: make the build less chatty
  * intel: Add drm_intel_gem_context_get_id to intel-symbols-check
  * intel: Add a getter for the intel_context ctx_id
  * etnaviv: add API to create etna_device from private dup() fd
  * etnaviv: add API to get drm fd from etna_device
  * intel: Add Geminilake PCI IDs
* Tue Nov 15 2016 sndirsch@suse.com
- update to 2.4.73
  * headers: Add README file
  * xd86drm: read more than 128 bytes of uevent in drmParsePciBusInfo
- update to 2.4.72
  * amdgpu: check parameters in amdgpu_query_gpu_info
  * intel: Export raw GEM mmap interfaces
  * intel: Migrate handle/name lookups from linear lists to hashtables
  * intel: Look prime handle up in handle hash table
  * Silence runtime complaints on platform devices
  * amdgpu: add the function to get the marketing name (v4)
  * intel: Add uthash.h to Makefile.sources.
  * amdgpu: Add amdgpu_asic_id.h to Makefile.sources.
  * freedreno: Add fd_ringbuffer_flush2 to symbol check.
  * headers: Sync drm{,_mode}.h with the kernel
  * Add drmModePageFlipTarget
  * intel: Add new symbols to intel-symbol-check
  * intel: Allow some codenames in INTEL_DEVID_OVERRIDE
  * add libsync.h helper
  * freedreno: sync uapi header
  * freedreno: add fence fd support
  * Return an -ENODEV from drmGetDevice() when no device was found.
* Tue Oct  4 2016 mimi.vx@gmail.com
- update to 2.4.71
  * amdgpu: expose the AMDGPU_GEM_CREATE_VRAM_CLEARED flag
  * Add drmModeAddFB2WithModifiers() which takes format modifiers
  * tests/amdgpu: update vce encRefPic addr mode to tiled
  * radeon: sync radeon_drm.h with the kernel
  * amdgpu: sync amdgpu_drm.h with the kernel
  * amdgpu: fix valgrind warnings caused by amdgpu_query_firmware_version
  * intel: Add new symbols to intel-symbol-check
  * amdgpu: add SI support
  * modetest: Also print the pixel clock
  * intel: Export pooled EU and min no. of eus in a pool
  * modetest: Adding amdgpu to module list
* Mon Jul 25 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.70:
  More bugfixes on top of 2.4.69!
* Sun Jul 24 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.69:
  A new libdrm release, in order to use the new vc4 ioctl in Mesa. A few
  bugfixes on top as well.
* Thu Apr 28 2016 sndirsch@suse.com
- update to 2.4.68
  * bugfixes
* Wed Apr 20 2016 sndirsch@suse.com
- removed no longer needed patch
  u_Fix-compilation-on-systems-that-don-t-provide-O_CLOE.patch
  (https://lists.freedesktop.org/archives/dri-devel/2016-April/105283.html)
* Tue Feb 16 2016 mimi.vx@gmail.com
- update to 2.4.67
  * fixes for amdgpu
  * adds KabyLake PCIids
  * Fix memory leak with drmModeGetConnectorCurrent()
* Wed Feb  3 2016 eich@suse.com
- Disable valgrind support for all architectures if not
  explicitely enabled by a macro (boo#963979).
* Wed Dec 30 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.66:
  This is mainly for introducing a new nouveau API. Lots of other
  changes as well.
* Mon Sep 21 2015 sndirsch@suse.com
- Update to version 2.4.65
  * bugfixes
* Wed Aug 19 2015 tobias.johannes.klausmann@mni.thm.de
- Add libdrm_amdgpu1 as a requirement for libdrm-devel
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 2.4.64:
  + amdgpu:
  - Improve amdgpu_vamgr_init.
  - Add flag to support 32bit VA address v4.
  - Make vamgr per device v2.
  + tests/amdgpu:
  - Include config.h first.
  - Remove unused local variable 'i'.
  + freedreno/msm:
  - Reorg ringbuffer struct.
  - Fix issue where same bo is on multiple rings.
  - Dump out submit info on error.
  + freedreno:
  - Add fd_pipe_wait_timeout().
  - Update freedreno-symbol-check.
  + tests: modetest: Accept connector names in addition to
    connector IDs.
  + libdrm:
  - Remove gratuitous blank lines.
  - Make indentation consistent.
- Use url to tarball as source.
* Fri Aug 14 2015 mimi.vx@gmail.com
- update baselibs.conf for AMDGPU
* Fri Aug 14 2015 mimi.vx@gmail.com
- update to version 2.4.6.3
  * This release adds AMDGPU driver, adds new AMD OLAND PCIids
* Mon Jul 27 2015 schwab@suse.de
- Disable valgrind support if not available
* Tue Jun 30 2015 sndirsch@suse.com
- Update to version 2.4.62
  * This release introduces the atomic and blob APIs, adds support
    for new devices (AMD Bonaire) and a new flag for coherent BOs
    in nouveau.
* Fri May  8 2015 sndirsch@suse.com
- Update to version 2.4.61
  * Release to fix regression in nouveau in 2.4.60, but brings lots
    of android changes and other fixes.
- deprecates reverse applied patches
  * U_nouveau-Do-not-add-most-bo-s-to-the-global-bo-list.patch
  * U_nouveau-make-nouveau-importing-global-buffers-comple.patch
* Wed Apr 29 2015 sndirsch@suse.com
- U_nouveau-Do-not-add-most-bo-s-to-the-global-bo-list.patch
  U_nouveau-make-nouveau-importing-global-buffers-comple.patch
  * reverse apply these patches in order to fix a regression in
    2.4.60 triggered by new legacy tray in GNOME 3.16.0 (fdo#89842)
* Wed Apr  8 2015 schwab@suse.de
- Build package libdrm_freedreno1 also on aarch64
* Fri Mar 20 2015 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.60:
  + bugfixes and cleanup
  + exynos improvements
* Sun Feb 22 2015 zombah@gmail.com
- Fix include directories
* Thu Feb 19 2015 zombah@gmail.com
- Add subpackage libdrm_tegra0 for Nvidia Tegra chips
* Mon Feb  9 2015 sndirsch@suse.com
- Update to version 2.4.59:
  * bugfixes
  * more Intel Skylake support
* Sun Sep 28 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.58:
  Build fixes for 32bit Systems.
* Sun Sep 28 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.57:
  + Intel Userptr support.
  + Android build support.
  + New "SI" and "CIK" PCI IDs for the libdrm Radeon graphics
    driver code.
  + DMA-BUF import/export helpers were added to libdrm's Freedreno
    driver support.
* Tue Jul 29 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.56:
  Libdrm 2.4.56 has been released. It fixes MSAA for the Radeon Hawaii GPU.
- Remove upstreamed patch:
  u_No-longer-hardcode-path-for-drm.h-include-in-qxl_drm.patch
* Fri Jul 25 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.55:
  + exynos: do not build fimg2d_test when building without libkms support.
  + radeon: Add missing header includes.
  + exynos: fix scaling factor computation in g2d_copy_with_scale
  + exynos: fix G2D_DOUBLE_TO_FIXED for non-integer input
  + exynos: fix coordinate computation in g2d_copy
  + intel: Add new userptr ioctl
  + intel: Sync typo fix from the kernel sources.
  + intel: Sync the command parser version parameter from kernel
  + freedreno: add chip-id property
  + freedreno: sync kernel header
  + drm: Add universal plane capability bit and plane type enums
  + exynos: prime: use drmPrime*() helpers
  + exynos_fimg2d_test: fix drmModeRmFB
  + eyxnos: install exynos tests if HAVE_INSTALL_TESTS
- Drop upstreamed patches:
  + libdrm-implicit-defs.diff (Patch1)
* Sun May 25 2014 afaerber@suse.de
- Enable valgrind support for armv6l and ppc64le
* Sun May  4 2014 tobias.johannes.klausmann@mni.thm.de
- Fix typos in package description
* Fri May  2 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.54:
  + Use signed location for drmModeSetPlane
  + nouveau: safen up nouveau_device list usage against concurrent access
  + amend previous commit to actually compile
  + modetest: add cursor support
  + freedreno: add missing fxn prototype
  + radeon: add Mullins chip family
  + radeon: add Mullins pci ids
  + Mark functions printf-like where possible
  + intel: Fix some format strings
  + libdrm: Remove extraneous parameter
  + tests: Use drmFreeVersion() instead of drmFree()
  + intel/chv: Add Cherryview PCI IDs
* Thu Apr 24 2014 sndirsch@suse.com
- u_No-longer-hardcode-path-for-drm.h-include-in-qxl_drm.patch:
  * No longer hardcode path for drm.h include in qxl_drm.h, i.e.
    handle it the same as in other <driver>_drm.h files; change
    required for KMS support in xf86-video-qxl (bnc#870501)
* Sat Apr 12 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.53:
  + drm: Implement drmCheckModesettingSupported() for FreeBSD
  + Enable libkms by default on DragonFly
  + freedreno: do not leak drmVersion
  + freedreno: fix license
  + freedreno: some msm-ring reset/flush fixes
  + freedreno: simplify device creation
  + freedreno: fix null ptr in error path
  + freedreno/kgsl: don't even bother trying CREATE_FD
  + freedreno: zero out unused field
  + modeprint: pretty print connector names
  + radeon: sync with radeon_drm.h from kernel headers
- Remove upstream patch: Patch3: U_freedreno_license_fix.patch
* Sun Feb 16 2014 afaerber@suse.de
- U_freedreno_license_fix.patch: Backport relicensing of freedreno
  DRM header from GPL-2.0 to MIT (bnc#860595).
* Tue Jan 21 2014 sndirsch@suse.com
- Update to version 2.4.52
  + intel: squash unused variable 'bo_gem'
  + intel: Handle malloc fails in context create
  + intel: Merge latest i915_drm.h
  + drm: Initialize or valgrind-clear modesetting ioctl arguments.
  + intel: Track whether a buffer is idle to avoid trips to the kernel.
  + tests/kmstest: support exynos
  + Mark debug_print with __attribute__ ((format(__printf__, 1, 0)))
  + intel: Create a new drm_intel_bo offset64 field.
  + freedreno: add fd_device_new_dup()
  + modetest: add the possibility to select the refresh frequency for a mode
* Wed Jan 15 2014 afaerber@suse.de
- Make libdrm-devel depend on libdrm_freedreno1 on arm
* Wed Jan 15 2014 afaerber@suse.de
- Add subpackage for freedreno (Qualcomm Adreno)
* Wed Jan  8 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.51:
  + radeon: avoid possible divide by 0 in surface manager
  + radeon: fix sumo2 pci id
  + intel/test_decode: Allow gen8 to be infered from the batch filenames
  + freedreno: add bo cache
  + freedreno/kgsl: fix crash introduced w/ bo-cache
  + freedreno: allow IB to different ringbuffer
* Wed Dec  4 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.50:
  + intel: Track known prime buffers for re-use
  + radeon: Update unaligned offset for 2D->1D tiling transition on SI
- Droped U_update-unaligned-offset-for-2D-1D-tiling-transition-on-SI.patch,
  included in this release
* Mon Nov 25 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.49:
  + intel: Use memset instead of VG_CLEAR
  + radeon: implement 2D tiling for CIK
  + radeon: handle P16 pipe configs for Hawaii
  + radeon: fix mipmap level 0 and 1 alignment for SI and CIK
  + radeon: don't overallocate stencil by 4 on SI and CIK
  + libdrm/mode: Update the encoder and connector defines
- Added U_update-unaligned-offset-for-2D-1D-tiling-transition-on-SI.patch:
  fdo#71983, resolves crasing on radeon SI chips wth 2.4.49
* Sat Nov 16 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.48:
  + radeon: add hawaii chip family
  + radeon: add hawaii pci ids
  + intel/bdw: Add broadwell chipset IDs
  + intel/bdw: Handle gen8 bufmgr_init
  + intel/bdw: Add gen8 to the decode init
  + intel/bdw: Update MI_BATCH_BUFFER_START for aub dumps
  + Revert "intel: Add support for GPU reset status query ioctl"
  + intel: Add support for GPU reset status query ioctl
  + intel: Add support for GPU reset status query ioctl
  + libdrm: bump to 2.4.48
  + Add DRM_MODE_PAGE_FLIP_ASYNC define
  + intel: Add the Gen6+ version of MI_REPORT_PERF_COUNT to
    intel_decode.c.
  + intel: Add MI_LOAD_REGISTER_MEM to intel_decode.c.
  + intel/bdw/aub: Update AUB trace block writes for 48-bit
    addressing.
  + nouveau: prevent undefined behavior in nouveau_pushbuf_reloc
    with gcc-4.8
* Sun Oct 27 2013 sndirsch@suse.com
- updated to re-uploaded 2.4.47 tarball with correct checksums
* Fri Oct 11 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.47:
  + libdrm: add missing DRM_CAP_TIMESTAMP_MONOTONIC
  + modetest fixes
  + radeon: add berlin pci ids
  + intel: Update package name and description in libdrm_intel.pc
  + freedreno fixes
  + radeon: Fix tiling mode index for 1D tiled depth/stencil
    surfaces on CIK
  + radeon: fix pitch alignment for non-power-of-two mipmaps on SI
  + drm: Synchronize the stereo 3D mode flags from the kernel headers
  + drm: Sync the DRM_SET_CLIENT_CAP ioctl definition
  + drm: Introduce a drmSetClientCap() wrapper
  + intel: Set bo size from lseek if kernel supports it
- Droped U_radeon-pad-CS-to-8-DW.patch, included in this release
* Tue Sep 17 2013 hrvoje.senjan@gmail.com
- Added U_radeon-pad-CS-to-8-DW.patch from upstream -- aligns the
  IB to 8 DWs. r6xx also require at least 4 DW alignment to avoid
  a hw bug.
* Thu Aug 29 2013 ro@suse.de
- buildrequire valgrind on the arch list that valgrind builds on
* Tue Jul  2 2013 hrvoje.senjan@gmail.com
- Update to version 2.4.46:
  + radeon: add CIK chip families
  + radeon: add Bonaire pci ids
  + radeon: add kabini pci ids
  + intel/aub: Sync the AUB defines with mesa's
  + intel/aub: Return early if we disable aub dumps
  + intel/aub: Implement a way to specify the output .aub filename
  + drm: add hotspot cursor interface support.
  + radeon: correct RADEON_GEM_WAIT_IDLE use
  + freedreno: add handle and name tracking
  + freedreno: add some asserts
  + freedreno: also remove from name table on bo delete
  + intel: Fix Haswell GT3 names.
  + intel: Adding more reserved PCI IDs for Haswell.
  + modetest: Make RGB565 pwetty too
* Tue May 21 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.45:
  The main motivation for this
  release is the changes in the radeon surface allocator, which helps fix
  multisample textures on the Radeon Cayman family chipsets.
  + radeon: add new SI pci ids
  + radeon: add new richland pci ids
  + radeon: add HAINAN family
  + radeon: add HAINAN pci ids
  + drm: add qxl drm header file
  + radeon: add RADEON_SURF_FMASK flag which disables 2D->1D tiling transition
  + freedreno: add gpu-id property
  + Add exynos_fimg2d_test to .gitignore
  + freedreno: add synchronization between mesa and ddx
  + intel: Add support for VEBOX ring (v2)
* Fri Apr 19 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.44:
  New release for radeonsi tiling support
  + drm: Fix error message in drmWaitVBlank
  + intel-decode: Fix gen6 HIER_DEPTH_BUFFER decoding
  + radeon: update radeon_drm.h to kernel last API additions v2
  + radeon: add si tiling support v5
  + intel: Fix Haswell CRW PCI IDs.
  + kms: Make libkms.h usable in C++
  + kms: Return a negative error code in kms_bo_create()
  + Remove unused header xf86mm.h.
  + makefiles: Add missing headers.
  + freedreno: add shifted reloc
  + modetest: Fix pitches, somewhat
  + modetest: Add support for all 16/32 bpp RGB formats
  + modetest: Print possible_crtcs for planes
  + modetest: Reduce the length of the connector type string
  + modetest: Pass format_info to fill_tiles functions
  + modetest: Add YUV420 support and fix YVU420 Cb/Cr ordering
* Wed Mar 27 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.43:
  + radeon: add pci ids for Richland APUs
  + intel_chipset: Merge intel-gpu-tools chipsets
  + tests: allow tests programs to be installed
  + tests: allow tests programs to be installed (cumulative patch)
  + intel: fix length mask for Gen5/Gen6 3DSTATE_CLEAR_PARAMS
  + libdrm/exynos: add test application for 2d gpu.
  + radeonsi: make sure tile_split field are not garbage
  + intel/aub: Actually run BLT batches on the blit ring.
  + nouveau: return error from pushbuf_validate
  + nouveau: add a way to override single pushbuffer memory limits
  + freedreno: add freedreno DRM
  + intel_chipset: Use parens around macro arguments
  + intel_chipset: Fix up VLV confusion
* Mon Mar 25 2013 jengelh@inai.de
- Remove unneeded dependency on libkms-devel
* Wed Feb 27 2013 dmueller@suse.com
- disable valgrind support for aarch64
* Tue Feb  5 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.42:
  + radeon: add OLAND family
  + radeon: add OLAND pci ids
  + man: fix manpage build instructions
  + intel: add more VLV PCI IDs
  + nouveau: use @PACKAGE_VERSION@ in libdrm_nouveau.pc
  + libdrm: remove DISTCHECK_CONFIGURE_FLAGS
  + configure.ac: bump version to 2.4.42 for release
  + radeon: Fix 1D tiling layout on SI.
  + man: Fix typo and use $() for make expressions
* Wed Jan 16 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.41:
  + radeon: add new SI pci id
  + nouveau: disallow pushbuf BOs in multiple memory types
  + nouveau: expose channel engine selection on kepler chipsets
  + intel: Remove the fence count contributions when clearing relocs
  + man: convert manpages to XML instead of plain troff
  + man: add drm.7 overview page
  + man: add drm-kms overview page
  + man: add drm-memory overview page
  + intel: Fix missing ETIME on BSD operating systems
  + drm/radeon: track global bo name and always return the same
  + man: disable man page building until David saves us all
  + libdrm_nouveau.pc: don't include I${includedir}/nouveau
  + libkms: fix memory leak in error path
  + libkms: return -EINVAL on fstat error
* Tue Nov  6 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.40:
  + radeon: add some new SI pci ids
  + radeon: fix unused-function warning
  + intel: Fix "properly test for HAS_LLC"
  + intel: Correct the word decoding for gen2 3DSTATE_LOAD_STATE_IMMEDIATE_1
  + configure.ac: Allow forcible disabling of Cairo support
  + intel: properly test for HAS_LLC
  + fix make distcheck
  + vmwgfx: No longer experimental
  + intel: add support for ValleyView
  + libdrm: man page infrastructure and a few sample man pages
  + intel: Mark bo's exported to prime as not reusable
  + libkms: link against libdrm
  + radeon: don't take the stencil-specific codepath for buffers without
    stencil
  + radeon: don't force stencil tile split to 0
  + radeon: fix stencil miptree allocation of combined ZS buffers on EG and
    SI
  + radeon: fix tile_split of 128-bit surface formats with 8x MSAA
  + radeon: Fix layout of linear aligned mipmaps on SI.
  + radeon: Memory footprint of SI mipmap base level is padded to powers of
    two.
  + radeon: Sampling pitch for non-mipmaps seems padded to slice alignment
    on SI.
  + initialize width/height fields in drmModeCrtc
  + omap: release lock also on error paths
* Thu Sep 27 2012 idonmez@suse.com
- Require libdrm_omap1-32bit only on ARM
* Sun Sep 23 2012 sndirsch@suse.com
- u_Fix-compilation-on-systems-that-don-t-provide-O_CLOE.patch
  * Fix compilation on systems that don't provide O_CLOEXEC.
    Patch suggestion by Thomas Klausner <wiz%%NetBSD.org@localhost>.
    See also http://mail-index.netbsd.org/pkgsrc-changes/2012/08/13/msg076887.html
* Thu Sep 20 2012 sndirsch@suse.com
- let libdrm-devel require libkms-devel
* Fri Aug 24 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.39:
  + radeon: add prime import/export support
  + intel: Use VG_CLEAR on the context destroy ioctl as well.
  + radeon: fix allocation of MSAA surfaces on r600-r700
  + radeon: align r600 msaa buffers to a multiple of macrotile size
  * num samples
  + tests/modetest: Add a forgotten return, needed for opensuse buildservice
  + omap: include omap_drm.h independently
* Mon Aug 13 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.38:
  + Bugfix release
* Sun Jul 22 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.37:
  + Put the proper context APIs in place.
- Add a patch to build 2.4.37 successfully!
  + Added N_0001-Add-a-forgotten-return-needed-for-opensuse-buildserv.patch
* Thu Jul  5 2012 sndirsch@suse.com
- build omap support only on %%arm platform
* Tue Jul  3 2012 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.4.36:
  + packaging changes:
  - nouveau.h was moved out from its subdirectory (upstream change)
  - lidrm_nouveau version bumped to 2
  - Removed --enable-nouveau-experimental-api from configure
    it is now stable and will build without it
  + new in this release:
  - Context API and wait render timeout API added to libdrm for Intel
* Mon Jul  2 2012 guillaume@opensuse.org
- Disable valgrind support for armv5 since valgrind only supports armv7
* Fri Jun 29 2012 sndirsch@suse.com
- U_intel-add-Ivy-Bridge-GT2-server-variant.patch
  * intel: add Ivy Bridge GT2 server variant (bnc#769209)
* Wed Jun 27 2012 guillaume@opensuse.org
- enable omapdrm support
* Tue May 29 2012 sndirsch@suse.com
- back to libdrm 2.4.33, since 2.4.34 currentlz requires Mesa git
  master changes for nouveau Mesa driver build
* Sat May 26 2012 crrodriguez@opensuse.org
- update to version 2.4.34, see NEWS for detail, here follows
  packaging changes only.
  + nouveau.h was moved out from its subdirectory (upstream change)
  + lidrm_nouveau version bumped to 2.
  + remove obsolete configure options.
  + Fix many more "implicit declarations" and "undefined references"
* Thu Apr 12 2012 vuntz@opensuse.org
- Update to version 2.4.33:
  + intel: add some PCI IDs for Haswell
  + omap: add omapdrm support
  + radeon: add TN surface support
- Changes from version 2.4.32:
  + Add valgrind support
  + Make drm/drm_fourcc.h portable to non-linux platforms
  + intel:
  - Add support for (possibly) unsynchronized maps
  - Add .aub file output support
  - Add support for overriding the PCI ID via an environment
    variable
  - Add decode for gen7 3DSTATE_WM, HIER_DEPTH_BUFFER
  - Add per-dword decode of gen7 3DPRIMITIVE
  + radeon: fix pitch alignment for scanout buffer
  + radeon_cs_setup_bo: Fix accounting if caller specified write
    and read domains
  + Build system improvements
- Add pkgconfig(valgrind) BuildRequires to build valgrind support.
* Sun Feb 26 2012 dmueller@suse.de
- fix build on arm
* Wed Feb 22 2012 dvaleev@suse.com
- don't package libdrm-intel on ppc, ppc64. As there is not intel
  cards
* Sat Feb 11 2012 jengelh@medozas.de
- Update to new upstream release 2.4.31
  * radeon: add surface allocator helper v10
  * intel: add sprite ioctl defines and struct for i915 sprite code
- Remove autoreconf call for now, there are no patches that
  would necessitate this
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Package shlibs separately according to policy
- Package description updates
* Mon Jan 16 2012 vljn@ovi.com
- Update to libdrm-2.4.30
  * required for lastest Mesa
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency from prjconf
* Wed Nov  2 2011 sndirsch@suse.com
- Update to libdrm 2.4.27
  * required for latest intel driver ...
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: move testing to %%check section
* Fri Jun 17 2011 vljn@ovi.com
- Update to libdrm 2.6.26
- obsoletes intel-Export-CONSTANT_BUFFER-addressing-mode.patch
- a bunch of fixes
- new Intel API for use by mesa
* Wed May 25 2011 sndirsch@novell.com
- install the binaries of dristat, drmstat, drmmodeprint and
  drmmodetest instead of the useless libtool wrappers ...
* Tue May 24 2011 eich@suse.de
- removed patch: enable_test_tools.diff.
  - Building and installing dristat and drmstat can be done
    from the spec file. Same is true for installing drmmodeprint
    and drmmodetest.
* Wed Jan  5 2011 sndirsch@novell.com
- intel-Export-CONSTANT_BUFFER-addressing-mode.patch
  * intel: Export CONSTANT_BUFFER addressing mode
* Mon Dec 20 2010 sndirsch@novell.com
- removed revert-09b1062.diff; due to Mesa 7.10-pre update no longer
  required/useful
* Sat Dec 11 2010 sndirsch@novell.com
- libdrm 2.4.23
  * drm: don't do the create the node ourselves if we have udev.
  * intel: Reorder need_fence vs fenced_command to avoid fences on
    gen4
  * tests: Update for ENOENT returns from unknown handles
* Sat Dec  4 2010 sndirsch@novell.com
- updated to git master commit #af3d282 (2010-12-03, still 2.4.22)
- obsoletes intel-initialize-bufmgr.bo_mrb_exec-unconditionally.patch
* Mon Nov  8 2010 sndirsch@novell.com
- intel-initialize-bufmgr.bo_mrb_exec-unconditionally.patch
  * no longer require kernels without BLT ring support (2.6.34 an
    before). (bnc #651989, bnc #651501)
* Sat Nov  6 2010 sndirsch@novell.com
- updated to git master commit #a52e61b (2010-11-02, still 2.4.22)
* Tue Nov  2 2010 sndirsch@novell.com
- updated to git master commit #d0a4f2e (2010-10-31, still 2.4.22)
- revert-09b1062.diff (to fix Mesa's nouveau driver build)
  * Revert "nouveau: Let the user choose the push buffer size."
    This reverts commit 09b1062628f2cbddb3ebae20e7b3b8a0a93acebf.
* Wed Sep 29 2010 sndirsch@novell.com
- libdrm 2.4.22
  * nouveau: fix thinko in drm version check
  * nouveau: fix drm version check some more
  * intel: Replace open-coded drmIoctl with calls to drmIoctl()
* Wed Sep 15 2010 sndirsch@novell.com
- updated to git master commit #7ec9a1e (2010-09-09, still 2.4.21)
* Sat Aug 28 2010 sndirsch@novell.com
- updated to git master commit #23287f0 (still 2.4.21)
- "--enable-nouveau-experimental-api" configure option appears to
  be obsolete meanwhile
- enabled build of VMWare's experimental API
* Tue Jul  6 2010 johannesobermayr@gmx.de
- bnc #620037
  * remove libdrm-204c76c.diff (reverse applied)
- silence some RPMLINT warnings
* Thu Jun 24 2010 sndirsch@suse.de
- updated to git master commit #726210f
  * various tiling related fixes for intel
* Tue Jun 15 2010 sndirsch@suse.de
- libdrm 2.4.21
- obsoletes commit-3506173.diff
- adjusted enable_test_tools.diff
- libdrm-204c76c.diff (reverse applied)
  * old nouveau gallium driver in Mesa still requires
    nouveau_class.h in libdrm
* Mon May 31 2010 sndirsch@suse.de
- intel: Use the correct size when allocating reloc_target_info
  array. Thomas tracked down this error with kdm and commit b509640
  (bnc #608149)
* Fri Apr  9 2010 sndirsch@suse.de
- libdrm 2.4.20
  * /usr/include/drm/ --> /usr/include/libdrm/
  * /usr/include/intel_bufmgr.h --> /usr/include/libdrm
* Thu Mar 18 2010 coolo@novell.com
- fix typo in description
* Wed Mar 17 2010 ro@suse.de
- update to 2.4.19 for Mesa-7.8
  * added nouveau driver
  * added kms wrapper library driver
* Sun Feb 28 2010 sndirsch@suse.de
- update to libdrm 2.4.18, which also obsoletes
  * intel-Account-for-potential-pinned-buffers-hogging-f.patch
  * intel-Handle-resetting-of-input-params-after-EINTR-d.patch
* Wed Feb 17 2010 sndirsch@suse.de
- intel-Account-for-potential-pinned-buffers-hogging-f.patch
  * intel: Account for potential pinned buffers hogging fences
    (bfo #25911)
- intel-Handle-resetting-of-input-params-after-EINTR-d.patch
  * intel: Handle resetting of input params after EINTR during
    SET_TILING (bfo #25475, bfo #25554)
* Wed Jan  6 2010 sndirsch@suse.de
- update to libdrm 2.4.17, which is part of Intel 2009Q4 release
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Fri Dec  4 2009 sndirsch@suse.de
- update to libdrm 2.4.16
  * "Here's the 2.4.16 release of libdrm.  There are a lot of
    changes this time, in particular we dropped the orphaned
    driver code from Linux and BSD and this release is now
    really just libdrm.  Going forward, the drm header files
    we ship in libdrm will be a straight copy from the linux
    kernel header files.  Once a feature is merged into the
    drm-next branch of Dave's kernel tree the header files can
    be copied from $kernel_src/usr/include/drm into libdrm and
    userspace support for the new functionality can be added."
* Fri Dec  4 2009 sndirsch@suse.de
- readded modeprint, modetest for intel driver
* Tue Dec  1 2009 sndirsch@suse.de
- libdrm 2.4.15_2009-12-01_8ffd2e1
  * update to git commit 8ffd2e1 (2009-12-01); required for
    xf86-video-intel 2.10 RC1
- adjusted enable_test_tools.diff
* Wed Nov  4 2009 ro@suse.de
- add "--enable-radeon-experimental-api --enable-udev"
  to configure arguments and package libdrm_radeon as well
* Thu Oct 29 2009 sndirsch@suse.de
- enable_test_tools.diff
  * enabled build of test tools (dristat, drmstat, modeprint,
    modeset)
* Wed Oct 28 2009 crrodriguez@opensuse.org
- libdrm-devel requires glibc-devel.
* Tue Sep 29 2009 sndirsch@suse.de
- libdrm 2.4.14
  * intel: adds support for G41, B43 and Ironlake
* Sat May 16 2009 sndirsch@suse.de
- libdrm 2.4.11
  * Two releases in one, so twice the usual tiny amount of changes.
    Both of the new libdrm_intel interfaces enable KMS fixes in the
    Intel 2D driver.
- enabled build of Nouveau's experimental API
* Sat Apr 18 2009 sndirsch@suse.de
- libdrm 2.4.9
  * Aka, the "kick jbarnes" release.  Not only did I push the
    broken speedup patch but I flubbed the version bump, so we get
    to go from 2.4.7 to 2.4.9.  Yay for me.
* Fri Apr 10 2009 sndirsch@suse.de
- libdrm 2.4.7
  * quick follow on release to 2.4.6 to fix an embarrasing
    build problem in the test suite when libudev is not available.
- obsoletes libdrm-commit-1faab66.diff
* Tue Apr  7 2009 sndirsch@suse.de
- libdrm 2.4.6
  * various fixes
- libdrm-commit-1faab66.diff
  * fixes build of 2.4.6
* Wed Feb 25 2009 sndirsch@suse.de
- libdrm 2.4.5
* Fri Jan 23 2009 sndirsch@suse.de
- Provides/Obsolete: libdrm23, i.e. get rid of confusing SLE10
  packages (bnc #468796)
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Oct 31 2008 sndirsch@suse.de
- libdrm 2.4.1
  * New libdrm release to fix the symbol name collision between
    Mesa 7.2 and libdrm_intel.  Also includes a fix for deadlock
    in non-GEM 2D, and support for aperture size checking in GEM.
  * Changes since commit a59ea02
  - intel: Rename dri_ and intel_ symbols to drm_intel_.
  - intel: Add dri_bufmgr_check_aperture support for bufmgr_gem.
  - nv50: symlink nv50_grctx.h to linux-core...
  - nv50: move context-related tables a separate header file
  - drm: missing init_mm symbol, compatibility fix
  - i915: Since FreeBSD doesn't have gem support yet, don't
    advertise it.
  - radeon: fix error in busmaster enable logic
  - radeon: fix some fallout from the busmaster disable cleanup
  - drm/i915: fix ioremap of a user address for non-root
    (CVE-2008-3831)
  - intel: Also total child_size of the target_bos. Partial fix
    [#17964].
  - [FreeBSD] We should use dev2unit() rather than minor()
  - [FreeBSD] This check isn't correct and causes at least mga
    to lockup.
* Tue Oct 21 2008 sndirsch@suse.de
- update to git commit a59ea02 (=2.4.1, Intel-2008-Q3-RC5)
  * avoid deadlock in intel_bufmgr_fake.
  * ioctl is not defined to return -errno. Don't count on ioctl
    returning -errno; use errno directly.
* Sun Oct 19 2008 sndirsch@suse.de
- libdrm 2.4.0 finally available
* Thu Oct  9 2008 sndirsch@suse.de
- updated to git commit ce40261, which is required by latest
  xf86-video-intel driver (Intel-2008-Q3-RC3)
* Fri Sep 26 2008 sndirsch@suse.de
- updated to git commit 2db8e0c, which is required by latest
  xf86-video-intel driver (Intel-2008-Q3-RC2)
* Wed Sep 24 2008 sndirsch@suse.de
- updated to git commit 973c634, which is required by latest
  xf86-video-intel driver (Intel-2008-Q3-RC1)
* Sun Aug 17 2008 sndirsch@suse.de
- updated to 2.4.0 prerelease (git commit a5381ca)
* Fri Jul  4 2008 sndirsch@suse.de
- updated to release 2.3.1
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Dec 27 2007 crrodriguez@suse.de
- fix library-without-ldconfig-postun warning
- libdrm.la had an empty dependency_libs, removed.
* Sat Dec  2 2006 sndirsch@suse.de
- updated to 2.3.0 (required by X.Org (Server) 7.2 RC3)
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
* Wed Jun 28 2006 sndirsch@suse.de
- updated to 2.0.2
  * various bugfixes in libdrm
* Wed Jun 21 2006 sndirsch@suse.de
- updated to current CVS (2006-06-21)
* Sat Apr 15 2006 sndirsch@suse.de
- updated to 2.0.1
  * various bugfixes in libdrm
* Sat Feb  4 2006 aj@suse.de
- xorg-x11-devel is not needed for build.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 23 2005 mls@suse.de
- Require main package in devel subpackage
* Wed Nov 30 2005 sndirsch@suse.de
- update to 2.0 branch (2005-11-30)
* Tue Nov  1 2005 sndirsch@suse.de
- updated to 1.0.5 (version Bump for new via header)
* Sat Oct 29 2005 sndirsch@suse.de
- call ldconfig in %%post
* Tue Oct 25 2005 sndirsch@suse.de
- updated to CVS 051025 (required for Mesa 6.4)
* Tue Oct  4 2005 sndirsch@suse.de
- added libdrm.so to filelist
* Sun Oct  2 2005 sndirsch@suse.de
- created package
